@@ -26,9 +26,9 @@ class TestQueries(TestCase):
         expected_result: str = """SELECT t1.KeyId AS CustomerKeyId, t1.id AS CustomerId, t1.card, t1.account, t2.KeyValue, SUM(t1.card) AS total_card, Unparseable_Custom_string AS cstring
 INTO #Biscuit
 FROM table1 t1
-INNER JOIN table2 t2 on t2.id = t1.id
+INNER JOIN table2 t2 on t2.id = CustomerId
 INNER JOIN table3 t3 on t3.KeyValue = t2.KeyValue
-WHERE t1.KeyId = 123456
+WHERE CustomerKeyId = 123456
 ORDER BY CustomerKeyId DESC, t2.KeyValue, cstring"""
         actual_result: str = QueryBuilder(self.select, self.where, self. innerjoin, self.innerjoin2, self._from, self.orderby).build()
         self.assertEqual(actual_result, expected_result)
